#######################
PyDMLineEdit
#######################

.. autoclass:: pydm.widgets.line_edit.PyDMLineEdit
   :members:
   :show-inheritance:
   :exclude-members: DisplayFormat


.. note::
   See `QLineEdit Documentation <https://pyqtgraph.readthedocs.io/en/latest/api_reference/widgets/QLineEdit.html>`_ for all inherited properties and methods.